import { Suspense } from "react";

import { HomeLoadingSkeleton } from "@/components/common/loading-skeleton";
import Footer from "@/components/layout/footer";
import Header from "@/components/layout/header-2/header-2";
import About from "@/components/sections/about/about";
import Testimonial from "@/components/sections/about/video-profile";
import Ads from "@/components/sections/home/ads";
import ArrivalProducts from "@/components/sections/home/arrival-products";
import BestSelling from "@/components/sections/home/best-selling";
import Blog from "@/components/sections/home/blog";
import Categories from "@/components/sections/home/categories";
import Features from "@/components/sections/home/features";
import Hero from "@/components/sections/home/hero";
import StatisticsList from "@/components/sections/home/statistics";
import { getClient } from "@/lib/react-query";
import { fetchBasicInfo } from "@/servers/actions/basicinfo-action";
import { fetchCategories } from "@/servers/actions/category-action";
import { fetchProjects } from "@/servers/actions/project-action";
import { fetchServices } from "@/servers/actions/service-action";
import { dehydrate, HydrationBoundary } from "@tanstack/react-query";


export default async function HomePage() {


	const queryClient = getClient();
	await Promise.all([
		queryClient.prefetchQuery({ queryKey: ["basicInfo"], queryFn: fetchBasicInfo }),
		queryClient.prefetchQuery({ queryKey: ["categories"], queryFn: fetchCategories }),
		queryClient.prefetchQuery({ queryKey: ["services"], queryFn: fetchServices }),
		queryClient.prefetchQuery({ queryKey: ["projects"], queryFn: fetchProjects }),
	]);

	const basicInfo = queryClient.getQueryData(["basicInfo"]) as any;
	console.log(basicInfo);


	return (
		<HydrationBoundary state={dehydrate(queryClient)}>
			<main className="min-h-screen">
				<Header />
				<Suspense fallback={<HomeLoadingSkeleton />}>
					<Hero />
					{basicInfo?.data?.show_sections_and_services === "on" && <Features />}
					{basicInfo?.data?.show_our_products_section === "on" &&
						<div>
							<ArrivalProducts />
							<Categories />
						</div>
					}
					{basicInfo?.data?.show_our_services_section === "on" && <BestSelling />}
					<About />
					{basicInfo?.data?.show_simulation_program_section === "on" && <Ads />}
					<Testimonial />
					<StatisticsList />
					<Blog />
					<Footer />
				</Suspense>
			</main>
		</HydrationBoundary>
	);
}
